import React from 'react'
import styles from './GiftList.less'
import { Flex } from 'antd-mobile'
import Url from '@/utils/Url'
import router from 'umi/router'

class GiftList extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      goldId: Url.getQueryString('g'),
      silverId: Url.getQueryString('s'),
      copperId: Url.getQueryString('c'),
      goldRewards: [],
      silverRewards: [],
      copperRewards: [],
      allRewards: [],
      showList: []
    }
  }

  componentDidMount() {
    this.NativeHook = this.props.NativeHook
    this.getRewardItem(this.state.goldId, 'gold')
    this.getRewardItem(this.state.silverId, 'silver')
    this.getRewardItem(this.state.copperId, 'copper')
  }

  componentDidUpdate(prveProps, prveState) {
    const state = this.state
    let { allRewards } = this.state
    if (prveState.goldRewards.length === 0 && state.goldRewards.length > 0) {
      allRewards = [...allRewards, ...state.goldRewards]
      this.setState({ allRewards })
    }
    if (prveState.silverRewards.length === 0 && state.silverRewards.length > 0) {
      allRewards = [...allRewards, ...state.silverRewards]
      this.setState({ allRewards })
    }
    if (prveState.copperRewards.length === 0 && state.copperRewards.length > 0) {
      allRewards = [...allRewards, ...state.copperRewards]
      this.setState({ allRewards })
    }
    if (prveState.allRewards.length != allRewards.length) {
      //重新排序
      allRewards.sort(this.compare("rewardValue"))
      const showList27 = allRewards.slice(0, 27)
      const showObj = new Map()
      for (let item of showList27) {
        showObj.set(item.rewardId, item)
      }
      const showList = [...showObj.values()].slice(0, 9)
      //console.log(showList)
      //flex空补充排列
      const leftNum = showList.length % 3
      if (leftNum > 0) {
        for (let i = 0; i < leftNum; i++) {
          showList.push({
            ratio: 0,
            rewardId: "000",
            rewardName: "",
            rewardType: 101,
            rewardValue: "0"
          })
        }
      }
      this.setState({ showList })
    }
  }

  compare = (propName) => {
    return (obj1, obj2) => {
      let val1 = obj1[propName];
      let val2 = obj2[propName];
      if (!isNaN(Number(val1)) && !isNaN(Number(val2))) {
        val1 = Number(val1);
        val2 = Number(val2);
      }
      if (val1 > val2) {
        return -1;
      } else if (val1 < val2) {
        return 1;
      } else {
        return 0;
      }
    }
  }

  //获取礼物清单
  getRewardItem = (lotteryId, type) => {
    this.NativeHook.call.getData({
      api: '/api-app/v1/activity/getRewardItem',
      params: { lotteryId },
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const _state = {}
        if (type === 'gold') {
          _state.goldRewards = res.data.list
        }
        if (type === 'copper') {
          _state.copperRewards = res.data.list
        }
        if (type === 'silver') {
          _state.silverRewards = res.data.list
        }
        this.setState(_state)
      }
    })
  }

  testLog = () => {
    console.log(this.state)
  }

  goDetail = () => {
    const { goldId, silverId, copperId } = this.state
    router.push(`/rewardsDetail?g=${goldId}&s=${silverId}&c=${copperId}`)
  }

  render() {
    const { showList } = this.state
    return (
      <div className={styles.giftList}>
        <Flex justify="between" className={styles.title} onClick={this.testLog}>
          <div className={styles.whiteLine}></div>
          <div className={styles.square}></div>
          <div>奖品清单</div>
          <div className={styles.square}></div>
          <div className={styles.whiteLine}></div>
        </Flex>
        <Flex className={styles.list} wrap="wrap" justify="between">
          {showList.map((item, i) => {
            return (
              <div key={i} className={styles['list-item']} style={{ opacity: item.rewardId === '000' ? 0 : 1 }}>
                <div className={styles['img-reward']}>
                  <img src={item.rewardIcon} />
                  <div className={styles.name}>{item.rewardName}</div>
                </div>
                <div className={styles.message}>{`价值${item.rewardValue}${item.lotteryPriceTypeName}`}</div>
              </div>
            )
          })}
        </Flex>
        <div className={styles.footer} onClick={this.goDetail}>查看更多礼品>></div>
      </div>
    )
  }
}

export default GiftList