import React from 'react'
import styles from './RewardsDetail.less'
import Url from '@/utils/Url'
import NativeHook from '@/utils/NativeHook'

class RewardsDetail extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      goldId: Url.getQueryString('g'),
      silverId: Url.getQueryString('s'),
      copperId: Url.getQueryString('c'),
      goldRewards: [],
      silverRewards: [],
      copperRewards: []
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = '奖品清单'
    this.getRewardItem(this.state.goldId, 'gold')
    this.getRewardItem(this.state.silverId, 'silver')
    this.getRewardItem(this.state.copperId, 'copper')
  }

  componentWillUnmount() {
    NativeHook.destroy()
  }

  //获取礼物清单
  getRewardItem = (lotteryId, type) => {
    NativeHook.call.getData({
      api: '/api-app/v1/activity/getRewardItem',
      params: { lotteryId },
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const _state = {}
        if (type === 'gold') {
          _state.goldRewards = res.data.list
        }
        if (type === 'copper') {
          _state.copperRewards = res.data.list
        }
        if (type === 'silver') {
          _state.silverRewards = res.data.list
        }
        this.setState(_state)
      }
    })
  }

  testLog = () => {
    console.log(this.state)
  }

  render() {
    const { goldRewards, silverRewards, copperRewards } = this.state
    return (
      <div className={styles.detail}>
        <table border="2" className={styles.table}>
          <tr style={{ backgroundColor: 'rgba(0,0,0,0.2)' }}>
            <th colSpan={3}>金猪</th>
          </tr>
          <tr>
            <th>奖项</th>
            <th>价值</th>
            <th>综合概率</th>
          </tr>
          {goldRewards.map((item, i) => (
            <tr key={i}>
              <th style={{ textAlign: 'left' }}>{item.rewardName}</th>
              <th>{item.rewardValue} 星钻/个</th>
              <th>{(item.ratio * 1000).toFixed(3)}‰</th>
            </tr>
          ))}
          <tr>
            <th colSpan={3} style={{ backgroundColor: 'rgba(0,0,0,0.2)' }}>银猪</th>
          </tr>
          <tr>
            <th>奖项</th>
            <th>价值</th>
            <th>综合概率</th>
          </tr>
          {silverRewards.map((item, i) => (
            <tr key={i}>
              <th style={{ textAlign: 'left' }}>{item.rewardName}</th>
              <th>{item.rewardValue} {item.lotteryPriceTypeName}/个</th>
              <th>{(item.ratio * 1000).toFixed(3)}‰</th>
            </tr>
          ))}
          <tr>
            <th colSpan={3} style={{ backgroundColor: 'rgba(0,0,0,0.2)' }}>铜猪</th>
          </tr>
          <tr>
            <th>奖项</th>
            <th>价值</th>
            <th>综合概率</th>
          </tr>
          {copperRewards.map((item, i) => (
            <tr key={i}>
              <th style={{ textAlign: 'left' }}>{item.rewardName}</th>
              <th>{item.rewardValue} 星钻/个</th>
              <th>{(item.ratio * 1000).toFixed(3)}‰</th>
            </tr>
          ))}
        </table>
      </div>
    )
  }
}

export default RewardsDetail