import React, { Fragment } from 'react'
import styles from './Home.less'
import { MyLottie } from '../components'
import { Flex, Modal, Toast, Result, Carousel } from 'antd-mobile';
import router from 'umi/router'
import { isIos, isAndroid, checkRewardType, getPriceName } from '../utils/base';
import NativeHook from '@/utils/NativeHook'
import Url from '@/utils/Url'

class Home extends React.Component {
  constructor(props) {
    super(props)
    this.a = 0
    this.state = {
      times: 1,
      timesList: [],
      userList: [],
      quantities: [],
      deBug: false,
      inIos: isIos(),
      inAndroid: isAndroid(),
      lotteryTime: 0,
      winRewards: [
      ],
      goldId: Url.getQueryString('g'),
      silverId: Url.getQueryString('s'),
      copperId: Url.getQueryString('c'),
      goldLotteryInfo: {},
      silverLotteryInfo: {},
      copperLotteryInfo: {},
      walletItems: [],
      balance: 0
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = '欢乐砸金猪'
    if (!this.state.deBug) {
      this.getLottery('gold')   //获取活动详情
      this.getLottery('silver')   //获取活动详情
      this.getLottery('copper')   //获取活动详情
    }
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if (prevState.winModal && !this.state.winModal) {
      this.setState({ winRewards: [] })
    }
  }

  componentWillUnmount() {
    NativeHook.destroy()
    if (this.timer) {
      clearTimeout(this.timer)
    }
    if (this.timeInterverl) {
      clearInterval(this.timeInterverl)
    }
  }

  //砸
  showHammer(showHammerIndex, lotteryId) {
    if (this.state.showHammerIndex || this.state.showBrokenLottieIndex) {
      console.log('正在砸，还没结束')
      return
    }
    const { goldLottie, goldHammerLottie, silverLottie, silverHammerLottie, copperLottie, copperHammerLottie } = this.state

    const lastLotteryId = lotteryId
    let hammerLottie = null
    //银猪
    if (showHammerIndex === 1 && silverLottie && silverHammerLottie) {
      hammerLottie = silverHammerLottie
      this.doHammer(showHammerIndex, lastLotteryId, silverHammerLottie, silverLottie, '银猪')
    }
    //砸金猪
    if (showHammerIndex === 2 && goldLottie && goldHammerLottie) {
      hammerLottie = goldHammerLottie
      this.doHammer(showHammerIndex, lastLotteryId, goldHammerLottie, goldLottie, '金猪')
    }
    //砸铜猪
    if (showHammerIndex === 3 && copperLottie && copperHammerLottie) {
      hammerLottie = copperHammerLottie
      this.doHammer(showHammerIndex, lastLotteryId, copperHammerLottie, copperLottie, '铜猪')
    }
    //开始抽奖
    if (hammerLottie && lotteryId) {
      this.lottery(lotteryId, hammerLottie)
    }
  }

  doHammer(index, lastLotteryId, hammerLottie, borkenLottie, pigName) {
    this.setState({ showHammerIndex: index, lastShowHammerIndex: index, lastLotteryId, lotteryEnd: false }, () => {
      hammerLottie.play()
      hammerLottie.addEventListener('complete', () => {
        const { lotteryEnd } = this.state
        if (lotteryEnd) {
          console.log(`${pigName}--砸--播放完毕`)
          //抽奖结果已返回，下面播放破碎动画
          this.stopHammer(hammerLottie)
          this.playBrokenLottie(borkenLottie, index)
        } else if (Date.now() - this.state.lotteryTime < 30 * 1000) {
          console.log(`${pigName}--30秒内等待--继续下一次砸`)
          //继续砸动作，抽奖接口还未返回数据
          this.reStartHammer(hammerLottie)
        } else if (Date.now() - this.state.lotteryTime > 30 * 1000) {
          //抽奖超时
          this.stopHammer(hammerLottie)
          Toast.fail('抽奖超时', 1)
        }
      })
    })
  }

  testLog() {
    console.log(this.state)
  }

  //获取余额
  getUserWallet(lotteryPriceType) {
    NativeHook.call.getData({
      api: '/api-app/v1/wallet/getUserWallet',
      params: {},
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const walletItems = res.data.walletItems || []
        let balance = 0
        for (let item of walletItems) {
          if (item.walletType === lotteryPriceType) {
            balance = item.balance
            break
          }
        }
        this.setState({ balance })
      }
    })
  }

  //获取活动详情
  getLottery(type) {
    const { goldId, silverId, copperId } = this.state
    const params = {}
    switch (type) {
      case 'gold':
        params.lotteryId = goldId
        break;
      case 'silver':
        params.lotteryId = silverId
        break;
      case 'copper':
        params.lotteryId = copperId
        break;
      default:
        params.lotteryId = ''
        break
    }
    NativeHook.call.getData({
      api: '/api-app/v1/activity/getLottery',
      params,
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const rewardItems = res.data.rewardItems || []
        for (let item of rewardItems) {
          if (!item.rewardIcon) continue
          const img = new Image()
          img.src = item.rewardIcon
        }
        const _state = {}
        _state.timesList = res.data.quantities ? res.data.quantities.split(',') : []
        _state.times = _state.timesList[0] || 1
        if (type === 'gold') {
          //获取活动中奖记录
          _state.activityId = res.data.activityId
          _state.goldLotteryInfo = res.data
          if (_state.activityId) {
            this.getActivityNewlyRewards(_state.activityId)
          }
          this.getUserWallet(res.data.lotteryPriceType)   //获取余额
        }
        if (type === 'silver') {
          _state.silverLotteryInfo = res.data
        }
        if (type === 'copper') {
          _state.copperLotteryInfo = res.data
        }
        this.setState(_state)
      } else {
        this.setState({ err: true, errMsg: type + res.msg })
      }
    })
  }

  //获取活动中奖记录
  getActivityNewlyRewards(activityId) {
    const params = {
      activityId
    }
    NativeHook.call.getData({
      api: '/api-app/v1/activity/getActivityNewlyRewards',
      params,
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        let userList = res.data.list
        checkRewardType(userList)
        this.setState({ userList })
      }
    })
  }

  //抽奖
  lottery(lotteryId, hammerLottie) {
    const params = {
      lotteryId,
      times: this.state.times
    }
    this.setState({ lotteryTime: Date.now() }, () => {
      NativeHook.call.postData({
        api: '/api-app/v1/activity/lottery',
        params,
        isDialogShow: false
      }, (res) => {
        if (!res) {
          Toast.fail('错误', 1.5)
          this.stopHammer(hammerLottie)
          return
        }
        if (res.success) {
          if (res.data.balance < 0) {
            console.log("余额不足")
            this.stopHammer(hammerLottie)
            this.goRecharge()
          } else {
            const { balance, winRewards } = res.data
            checkRewardType(winRewards)
            this.setState({ lotteryEnd: true, balance, winRewards })
          }
        } else {
          Toast.fail(res.msg, 1.5)
          this.stopHammer(hammerLottie)
        }
      })
    })
  }

  //停止砸动作
  stopHammer(hammerLottie) {
    hammerLottie.stop()
    this.setState({ showHammerIndex: null })
  }

  //重新开始砸
  reStartHammer(hammerLottie) {
    hammerLottie.stop()
    hammerLottie.play()
  }

  //开始播放破碎动画
  playBrokenLottie(borkenLottie, showBrokenLottieIndex) {
    borkenLottie.setSpeed(3)
    this.setState({ showBrokenLottieIndex }, () => {
      borkenLottie.play()   //播放破碎
    })
  }

  showToast(resString) {
    Toast.info(resString || 'showToast', 1)
  }

  //保存猪的动效
  savePigLottie(myLottie, type) {
    myLottie.addEventListener('complete', () => {
      console.log('猪--破碎--播放完毕')
      this.setState({ showBrokenLottieIndex: null }, () => {
        myLottie.stop()
        this.setState({ winModal: true })
      })
    })
    if (type === 'silver') {
      this.setState({ silverLottie: myLottie })
    }
    if (type === 'gold') {
      this.setState({ goldLottie: myLottie })
    }
    if (type === 'copper') {
      this.setState({ copperLottie: myLottie })
    }
  }

  //选择次数
  pickTimes(times) {
    this.setState({ times, openTimes: false })
  }

  //存储敲击
  saveHammerLottie(hammerLottie, type) {
    if (type === 'silver') {
      this.setState({ silverHammerLottie: hammerLottie })
    }
    if (type === 'gold') {
      this.setState({ goldHammerLottie: hammerLottie })
    }
    if (type === 'copper') {
      this.setState({ copperHammerLottie: hammerLottie })
    }
  }

  goRecharge() {
    NativeHook.go.recharge(() => {
      // 充值成功 刷新余额
      this.getUserWallet(this.state.goldLotteryInfo.lotteryPriceType || 11)
    })
  }

  //关闭
  handleClose() {
    console.log('关闭网页')
    NativeHook.call.close()
  }

  //存储中奖礼花动画
  saveWinLottie(winLottie) {
    winLottie.setSpeed(2)
    let showWinLottie = false
    if (this.state.winRewards.length > 0) {
      showWinLottie = true
    }
    this.setState({ showWinLottie, winLottie }, () => {
      if (showWinLottie) {
        winLottie.play()
      }
    })
    winLottie.addEventListener('complete', () => {
      console.log('礼花--播放完毕')
      winLottie.stop()
      this.setState({ showWinLottie: false })
    })
  }

  //再玩一次
  playAgain() {
    const { lastShowHammerIndex, lastLotteryId } = this.state
    this.setState({ winModal: false }, () => {
      this.timer = setTimeout(() => {
        this.showHammer(lastShowHammerIndex, lastLotteryId)
      }, 300);
    })
  }

  //打开砸几次
  handleTimesPop() {
    const { timesList, openTimes } = this.state
    if (timesList.length === 0) {
      return
    }
    this.setState({ openTimes: !openTimes })
  }

  closeWinModal() {
    this.setState({ winModal: false })
  }

  render() {
    const { err, errMsg, showHammerIndex, goldLottie, silverLottie, silverHammerLottie, times, openTimes, timesList, userList, showBrokenLottieIndex, goldHammerLottie, copperLottie, copperHammerLottie } = this.state
    const { goldId, silverId, copperId, winRewards, goldLotteryInfo, silverLotteryInfo, copperLotteryInfo } = this.state
    const wined = winRewards.length > 0
    return (
      <Fragment>
        {!err && (
          <div className={styles.wrapper}>
            <img className={styles['bg-top']} src={require('@/assets/bg-top.png')} />
            <div className={styles.content}>
              <img className={styles['icon-close']} src={require('@/assets/icon_close.png')} onClick={this.handleClose.bind(this)} />
              <div className={styles.rule} onClick={() => router.push('/rule')}>活动规则</div>
              <img className={styles.title} src={require('@/assets/img_title.png')} onClick={this.testLog.bind(this)} />
              {/* 金猪 */}
              <Flex align="baseline" justify="between">
                {/* 银猪 */}
                <div className={styles['wrapper-pig']}>
                  <img
                    style={{ display: (showBrokenLottieIndex === 1 || !silverLottie || !silverHammerLottie) ? 'none' : 'block' }}
                    className={styles['img-silver']}
                    src={require('@/assets/img_silver.png')}
                    onClick={this.showHammer.bind(this, 1, silverId)}
                  />
                  <MyLottie
                    className={styles['lottie-silver-hammer']}
                    id="hammer-silver"
                    path='http://sp.qn.paqukeji.com/goldPig/hammer.json'
                    style={{ display: showHammerIndex === 1 ? 'block' : 'none' }}
                    saveLottie={lottie => this.saveHammerLottie(lottie, 'silver')}
                  />
                  <MyLottie
                    className={styles['lottie-silver-pig']}
                    id="silverId"
                    path='http://sp.qn.paqukeji.com/goldPig/pig_silver.json'
                    style={{ display: showBrokenLottieIndex === 1 ? 'block' : 'none' }}
                    saveLottie={lottie => this.savePigLottie(lottie, 'silver')}
                  />
                  <div className={styles['text']}>银猪 {silverLotteryInfo.lotteryPrice} {getPriceName(silverLotteryInfo.lotteryPriceType)}</div>
                </div>
                {/* 金猪 */}
                <div className={styles['wrapper-pig']}>
                  <img
                    style={{ display: (showBrokenLottieIndex === 2 || !goldLottie || !goldHammerLottie) ? 'none' : 'block' }}
                    className={styles['img-gold']}
                    src={require('@/assets/img_gold.png')}
                    onClick={this.showHammer.bind(this, 2, goldId)}
                  />
                  <MyLottie
                    className={styles['lottie-gold-hammer']}
                    id="hammer-gold"
                    path='http://sp.qn.paqukeji.com/goldPig/hammer.json'
                    style={{ display: showHammerIndex === 2 ? 'block' : 'none' }}
                    saveLottie={lottie => this.saveHammerLottie(lottie, 'gold')}
                  />
                  <MyLottie
                    className={styles['lottie-gold-pig']}
                    id="goldId"
                    path='http://sp.qn.paqukeji.com/goldPig/pig_gold.json'
                    style={{ display: showBrokenLottieIndex === 2 ? 'block' : 'none' }}
                    saveLottie={lottie => this.savePigLottie(lottie, 'gold')}
                  />
                  <div className={styles['text']}>金猪 {goldLotteryInfo.lotteryPrice} {getPriceName(goldLotteryInfo.lotteryPriceType)}</div>
                </div>
                {/* 铜猪 */}
                <div className={styles['wrapper-pig']}>
                  <img
                    style={{ display: (showBrokenLottieIndex === 3 || !copperLottie || !copperHammerLottie) ? 'none' : 'block' }}
                    className={styles['img-silver']}
                    src={require('@/assets/img_copper.png')}
                    onClick={this.showHammer.bind(this, 3, copperId)}
                  />
                  <MyLottie
                    className={styles['lottie-silver-hammer']}
                    id="hammer-copper"
                    path='http://sp.qn.paqukeji.com/goldPig/hammer.json'
                    style={{ display: showHammerIndex === 3 ? 'block' : 'none' }}
                    saveLottie={lottie => this.saveHammerLottie(lottie, 'copper')}
                  />
                  <MyLottie
                    className={styles['lottie-silver-pig']}
                    id="copperId"
                    path='http://sp.qn.paqukeji.com/goldPig/pig_copper.json'
                    style={{ display: showBrokenLottieIndex === 3 ? 'block' : 'none' }}
                    saveLottie={lottie => this.savePigLottie(lottie, 'copper')}
                  />
                  <div className={styles['text']}>铜猪 {copperLotteryInfo.lotteryPrice} {getPriceName(copperLotteryInfo.lotteryPriceType)}</div>
                </div>
              </Flex>
              {/* 砸几次 */}
              <div className={styles['pop-times']} hidden={!openTimes}>
                {timesList.map((item, i) => {
                  return (
                    <div key={i} className={styles['item-times']} onClick={this.pickTimes.bind(this, item)}>砸{item}次</div>
                  )
                })}
                <img className={styles['icon-white-trigon']} src={require('@/assets/icon_white_trigon.png')} />
              </div>
              <Flex justify="between" className={styles.bar}>
                <div className={styles['button-wrapper']} onClick={this.handleTimesPop.bind(this)}>
                  <Flex align="center" justify="center">
                    <div>砸{times}次</div>
                    {timesList.length > 1 && (
                      <img
                        className={styles['icon-trigon']}
                        src={require('@/assets/icon_trigon.png')}
                        style={{ transform: openTimes ? 'rotate(180deg)' : 'unset' }}
                      />
                    )}
                  </Flex>
                </div>
                <div className={styles['button-wrapper']} onClick={() => router.push('/winnerList?id=' + this.state.activityId)}>
                  中奖记录
                </div>
              </Flex>
              <WinnerList userList={userList} refresh={this.getActivityNewlyRewards.bind(this, this.state.activityId)} />
            </div>
            {/* 充值栏 */}
            <Flex className={styles.footer} align="center">
              <img className={styles['icon-star']} src={require('@/assets/icon_star.png')} />
              <div className={styles.money}>{this.state.balance || 0}</div>
              <div className="color-white font-28" onClick={this.goRecharge.bind(this)}>充值</div>
              <img className={styles['icon-right']} src={require('@/assets/icon_right.png')} onClick={this.goRecharge.bind(this)} />
            </Flex>
            {/* 中奖弹窗 */}
            <Modal
              className={`${styles.winModal}`}
              visible={this.state.winModal}
              transparent
              maskClosable
              onClose={this.closeWinModal.bind(this)}
              wrapProps={{ onTouchStart: this.onWrapTouchStart }}
            >
              <MyLottie
                className={styles['lottie-winFire']}
                style={{ display: this.state.showWinLottie ? 'block' : 'none' }}
                id="winLottie"
                path='http://sp.qn.paqukeji.com/goldPig/win.json'
                saveLottie={this.saveWinLottie.bind(this)}
              />
              <div className={styles['winModal-content']}>
                <img className={styles.title} src={require('@/assets/winModal_title.png')} />
                {wined ? (
                  <Fragment>
                    <div className="font-32 color-white">-获得以下奖品-</div>
                    {/* 礼物列表 */}
                    <Flex align="center" wrap="nowrap" className={styles['list-gift']} justify={winRewards.length > 2 ? 'start' : 'center'}>
                      {winRewards.map((item, i) => {
                        return (
                          <div key={i} className={styles['list-gift-item']} style={{ position: 'relative' }}>
                            <div style={{ position: 'absolute', top: 0, right: 0, bottom: 0, left: 0, opacity: 0.1, backgroundColor: '#fff', borderRadius: '0.08rem' }}></div>
                            <img className={styles['img-gift']} src={item.rewardIcon} />
                            <div className={styles.giftName}>{item.rewardName}</div>
                            <div className={styles.giftNum}>x{item.quantity}</div>
                          </div>
                        )
                      })}
                    </Flex>
                  </Fragment>
                ) : (
                    <div className="font-32 color-white" style={{ padding: '1rem 0rem' }}>-很遗憾，大奖与你插肩而过-</div>
                  )}
                <div className={styles['button-modal']} onClick={this.playAgain.bind(this)}>再玩一次</div>
              </div>
            </Modal>
          </div>
        )}
        {err && (
          <Result
            img={<img style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
            title="信息错误"
            message={errMsg}
          />
        )}

        {/* 动画 */}
        {/* <MyLottie
          style={{ width: '3rem', height: '3rem' }}
          id="mylottie"
          path='http://sp.qn.paqukeji.com/goldPig/win.json'
          autoplay
          loop
        /> */}
      </Fragment>
    )
  }
}

export default Home


//中奖用户栏
function WinnerList(props) {

  const renderList = (userList) => {
    const result = []
    for (let i in userList) {
      i = Number(i)
      if ((i === 0 || (i % 3 === 0)) && userList[i + 2]) {
        const first = userList[i]
        const second = userList[i + 1]
        const third = userList[i + 2]
        result.push(
          <div key={i}>
            <Flex className={styles['item-user']} align="center">
              <div className={styles.name}>{`恭喜${first.userName}`}</div>
              <div className={styles.gift}>{`获得了 ${first.rewardName} `}</div>
              <div style={{ display: 'inline-block' }}>{` x${first.quantity}`}</div>
            </Flex>
            <Flex className={styles['item-user']} align="center">
              <div className={styles.name}>{`恭喜${second.userName}`}</div>
              <div className={styles.gift}>{`获得了 ${second.rewardName} `}</div>
              <div style={{ display: 'inline-block' }}>{` x${second.quantity}`}</div>
            </Flex>
            <Flex className={styles['item-user']} align="center">
              <div className={styles.name}>{`恭喜${third.userName}`}</div>
              <div className={styles.gift}>{`获得了 ${third.rewardName} `}</div>
              <div style={{ display: 'inline-block' }}>{` x${third.quantity}`}</div>
            </Flex>
          </div>
        )
      }
    }
    return result
  }

  const { userList } = props
  return (
    <div className={styles['list-winner']}>
      <img className={styles['list-title']} src={require('@/assets/img_list_title.png')} onClick={props.refresh} />
      <div className={styles['list-winner-content']}>
        {userList.length > 0 && userList.length > 2 && (
          <Carousel className={styles.notice}
            vertical
            dots={false}
            dragging={false}
            swiping={false}
            autoplay
            infinite
            speed={400}
            autoplayInterval={4000}
          >
            {renderList(userList)}
          </Carousel>
        )}
        {userList.length > 0 && userList.length < 3 && (
          <div>
            {userList.map((userInfo, i) => {
              return (
                <Flex key={i} className={styles['item-user']} align="center">
                  <div className={styles.name}>{`恭喜${userInfo.userName}`}</div>
                  <div className={styles.gift}>{`获得了 ${userInfo.rewardName} `}</div>
                  <div style={{ display: 'inline-block' }}>{` x${userInfo.quantity}`}</div>
                </Flex>
              )
            })}
          </div>
        )}
        {userList.length === 0 && <div className={styles['item-user']} style={{ textAlign: 'center' }}>暂无中奖用户</div>}
      </div>
    </div>
  )
}