
//我的中奖记录
import styles from './WinnerList.less'
import router from 'umi/router'
import React, { Fragment } from 'react'
import { Flex, Result, ActivityIndicator, Toast } from 'antd-mobile'
import { checkRewardType } from '../utils/base';
import NativeHook from '@/utils/NativeHook'
import * as Format from '@/utils/Format'
import Url from '@/utils/Url'


class WinnerList extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      list: [
        // {
        //   "userName": null,
        //   "userAvatar": null,
        //   "rewardId": "35951954886761",
        //   "rewardType": 101,
        //   "quantity": 1,
        //   "lotteryTime": "1582284256257",
        //   "rewardName": "怦然心动",
        //   "rewardIcon": "http://media.sbqn.laylib.com/gift/icon/b021693fa43746509aa89748ec3c75b4.png",
        // }
      ],
      loading: false,
      firstLoad: true,
      pagination: {
        pageSize: 20,
        pageIndex: 1,
        total: 0
      },
      activityId: Url.getQueryString('id')
    }
  }

  componentDidMount() {
    document.title = '中奖记录'
    NativeHook.init()
    this.getActivityRewardList(1)
  }

  componentWillUnmount() {
    NativeHook.destroy()
    // 移除滚动监听
    if(this.listRef) {
      this.listRef.removeEventListener('scroll', this.bindScroll);
    }
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  bindScroll = (event) => {
    //console.log(this.listRef.scrollHeight, this.listRef.scrollTop, this.listRef.clientHeight)
    // 滚动的高度
    const scrollTop = this.listRef.scrollTop
    // 视窗高度
    const clientHeight = this.listRef.clientHeight
    // 页面高度
    const scrollHeight = this.listRef.scrollHeight
    // 距离页面底部的高度
    const height = scrollHeight - scrollTop - clientHeight;
    // 判断距离页面底部的高度 
    if (height <= 500) {
      if (this.state.hasNext) {
        this.getActivityRewardList(this.state.pagination.pageIndex + 1)   //加载下一页
      }
    }
  }

  getActivityRewardList(pageIndex) {
    const { activityId } = this.state
    const params = {
      activityId,
      pageIndex
    }
    if(this.state.loading) return
    this.setState({ loading: true }, ()=>{
      NativeHook.call.getData({
        api: '/api-app/v1/activity/getActivityRewardList',
        params,
        isDialogShow: false
      }, (res) => {
        if (res.success) {
          const { total, pageSize } = res.data
          let { hasNext, pagination, list } = this.state
          if (pageIndex > 1) {
            list = [...list, ...res.data.list]
          } else {
            list = res.data.list
          }
          checkRewardType(list)
          if (pageIndex * pagination.pageSize < total) {
            hasNext = true
          } else {
            hasNext = false
          }
          pagination.pageIndex = pageIndex
          pagination.pageSize = pageSize
          const lastFirstLoad = this.state.firstLoad
          this.setState({ loading: false, list, hasNext, pagination, firstLoad: false }, ()=>{
            if (lastFirstLoad) {
              this.timer = setTimeout(() => {
                this.listRef.addEventListener('scroll', this.bindScroll)
              }, 1000);
            }
          })
        } else {
          this.setState({ loading: false, firstLoad: false }, () => {
            Toast.fail(res.msg)
            console.log(res.msg)
          })
        }
      })
    })
  }

  testLog() {
    console.log(this.state)
  }  

  render() {
    const { list, loading, err, errMag, firstLoad } = this.state
    return (
      <div className={styles.winner}>
        {firstLoad && <ActivityIndicator className={styles.firstLoadLoading} toast animating={true} text="加载中" />}
        {
          !firstLoad && err && (
            <Result
              img={<img style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
              title="信息错误"
              message={errMag}
            />
          )
        }
        {!firstLoad && !err && (
          <Fragment>
            <div className={styles.title} onClick={ this.testLog.bind(this) }>中奖记录</div>
            <div className={styles.list} ref={ ref => this.listRef = ref }>
              {list.map((item, i) => {
                return (
                  <div key={i} className={styles['list-item']}>
                    <Flex justify="between">
                      <div>{`获得 ${item.rewardName} x${item.quantity}`}</div>
                      <div className={styles.time}>{Format.date(item.lotteryTime, 'yyyy-MM-dd HH:mm')}</div>
                    </Flex>
                  </div>
                )
              })}
              <div style={{ textAlign: 'center' }}>
                {loading && <ActivityIndicator animating className={styles.loadingMore}/>}
              </div>
            </div>
          </Fragment>
        )}
        <div className={styles.footer}>
          <div className={styles.button} onClick={() => router.goBack()}>返回</div>
        </div>
      </div>
    )
  }
  
}

export default WinnerList